# -*- coding: utf-8 -*-
from distutils.core import setup
setup(
  name='pypbe',
  packages=['pypbe'],
  version='0.12',
  description='Module to calculate Point Buy Equivalent for Tabletop RPG',
  author='Eric Strong',
  author_email='dr.eric.strong@gmail.com',
  url='https://github.com/drericstrong/pypbe',
  download_url='https://github.com/drericstrong/pypbe/tarball/0.12',
  keywords=['RPG', 'Pathfinder', 'D&D', 'Tabletop', 'Point Buy', 'Point Buy Equivalent'],
  classifiers=[],
)
